/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 package org.apache.stonehenge.stocktrader.services;

import org.tempuri.ITradeServices;
import org.apache.stonehenge.stocktrader.*;
import org.apache.stonehenge.stocktrader.dal.DAOException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import com.ibm.websphere.samples.trade.*;

import javax.jws.WebParam;
import javax.jws.WebService;
import java.util.List;

@WebService(endpointInterface = "org.tempuri.ITradeServices")
public class TradeServiceImpl implements ITradeServices {
    private static final Log logger = LogFactory.getLog(TradeServiceImpl.class);

	private final TraderServiceManager mgr = new TraderServiceManager();
    private final BeanFactory factory = new BeanFactory();
    
    public EmptyMethodActionResponse emptyMethodAction(
            @WebParam(name = "emptyMethodAction", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") EmptyMethodAction emptyMethodAction) {
        throw new UnsupportedOperationException("emptyMethodAction unimplemented");
    }

    public void isOnline(
            @WebParam(name = "isOnline", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") IsOnline isOnline) {
        if (logger.isDebugEnabled()) {
			logger.debug("TradeServiceImpl.isOnline()");
		}
    }

    public LoginResponse login(
            @WebParam(name = "login", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") Login login) {
        CustomAccountBean param;
		try {
			param = mgr.login(login.getUserID(), login.getPassword());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		LoginResponse response = new LoginResponse();
		response.setLoginReturn(factory.toAccount(param));
		return response;
    }

    public GetOrdersResponse getOrders(
            @WebParam(name = "getOrders", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") GetOrders getOrders) {
        List<CustomOrderBean> orders;
		try {
			orders = mgr.getOrders(getOrders.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetOrdersResponse response = new GetOrdersResponse();
		ArrayOfOrderDataBean param = new ArrayOfOrderDataBean();
        // FIXED: used array for metro generated code
        param.getOrderDataBean().addAll(factory.toOrderList(orders));
//		param.setOrderDataBean(toArray(orders));
		response.setGetOrdersReturn(param);
		return response;
    }

    public GetAccountDataResponse getAccountData(
            @WebParam(name = "getAccountData", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") GetAccountData getAccountData) {
        CustomAccountBean accountData;
		try {
			accountData = mgr.getAccountData(getAccountData.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetAccountDataResponse getAccountDataResponse = new GetAccountDataResponse();
		getAccountDataResponse.setGetAccountDataReturn(factory.toAccount(accountData));
		return getAccountDataResponse;
    }

    public GetAccountProfileDataResponse getAccountProfileData(
            @WebParam(name = "getAccountProfileData", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") GetAccountProfileData getAccountProfileData) {
        CustomAccountProfileBean accountProfileData;
		try {
			accountProfileData = mgr
					.getAccountProfileData(getAccountProfileData.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetAccountProfileDataResponse response = new GetAccountProfileDataResponse();
		response.setGetAccountProfileDataReturn(factory.toAccountProfile(accountProfileData));

		return response;
    }

    public UpdateAccountProfileResponse updateAccountProfile(
            @WebParam(name = "updateAccountProfile", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") UpdateAccountProfile updateAccountProfile) {
        CustomAccountProfileBean accountProfile = factory.toCustomAccountProfileBean(updateAccountProfile.getProfileData());
		CustomAccountProfileBean param;
		try {
			param = mgr.updateAccountProfile(accountProfile);
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}

		UpdateAccountProfileResponse response = new UpdateAccountProfileResponse();
		response.setUpdateAccountProfileReturn(factory.toAccountProfile(param));
		return response;
    }

    public LogoutResponse logout(
            @WebParam(name = "logout", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") Logout logout) {
        try {
			mgr.logout(logout.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		LogoutResponse response = new LogoutResponse();
		return response;
    }

    public BuyResponse buy(
            @WebParam(name = "buy", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") Buy buy) {
        CustomOrderBean order;
		try {
			order = mgr
					.buy(buy.getUserID(), buy.getSymbol(), buy.getQuantity());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		BuyResponse buyResponse = new BuyResponse();
		buyResponse.setBuyReturn(factory.toOrder(order));
		return buyResponse;
    }

    public SellResponse sell(
            @WebParam(name = "sell", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") Sell sell) {
        CustomOrderBean param;
		try {
			param = mgr.sell(sell.getUserID(), sell.getHoldingID(), sell
					.getOrderProcessingMode());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		SellResponse response = new SellResponse();
		response.setSellReturn(factory.toOrder(param));
		return response;
    }

    public GetHoldingsResponse getHoldings(
            @WebParam(name = "getHoldings", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") GetHoldings getHoldings) {
        List<CustomHoldingBean> holdingBeans;
		try {
			holdingBeans = mgr.getHoldings(getHoldings.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetHoldingsResponse response = new GetHoldingsResponse();
		ArrayOfHoldingDataBean param = new ArrayOfHoldingDataBean();
        
        // FIXED: used array for metro generated code
        param.getHoldingDataBean().addAll(factory.toHoldingDataList(holdingBeans));
//		param.setHoldingDataBean(toArray(holdingBeans));
		response.setGetHoldingsReturn(param);
		return response;
    }

    public RegisterResponse register(
            @WebParam(name = "register", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") Register register) {
        CustomAccountBean param;
		try {
			param = mgr.register(register.getUserID(), register.getPassword(),
					register.getFullname(), register.getAddress(), register
							.getEmail(), register.getCreditcard(), register
							.getOpenBalance());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		RegisterResponse response = new RegisterResponse();
		response.setRegisterReturn(factory.toAccount(param));
		return response;
    }

    public GetClosedOrdersResponse getClosedOrders(
            @WebParam(name = "getClosedOrders", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") GetClosedOrders getClosedOrders) {
        List<CustomOrderBean> closedOrders;
		try {
			closedOrders = mgr.getClosedOrders(getClosedOrders.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetClosedOrdersResponse response = new GetClosedOrdersResponse();
		ArrayOfOrderDataBean arrayOfOrderBean = new ArrayOfOrderDataBean();
        // FIXED: used array for metro generated code
        arrayOfOrderBean.getOrderDataBean().addAll(factory.toOrderList(closedOrders));
//		arrayOfOrderBean.setOrderDataBean(toArray(closedOrders));
		response.setGetClosedOrdersReturn(arrayOfOrderBean);
		return response;
    }

    public GetMarketSummaryResponse getMarketSummary(
            @WebParam(name = "getMarketSummary", targetNamespace = "http://trade.samples.websphere.ibm.com",
                    partName = "parameters") GetMarketSummary getMarketSummary) {
        CustomMarketSummaryBean param;
		try {
			param = mgr.getMarketSummary();
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetMarketSummaryResponse response = new GetMarketSummaryResponse();
		response.setGetMarketSummaryReturn(factory.toMarketSummaryData(param));
		return response;
    }

    public GetQuoteResponse getQuote(
            @WebParam(name = "getQuote", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") GetQuote getQuote) {
        CustomQuoteBean param;
		try {
			param = mgr.getQuote(getQuote.getSymbol());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetQuoteResponse response = new GetQuoteResponse();
		response.setGetQuoteReturn(factory.toQuote(param));
		return response;
    }

    public GetHoldingResponse getHolding(
            @WebParam(name = "getHolding", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") GetHolding getHolding) {
        CustomHoldingBean holding;
		try {
			holding = mgr.getHolding(getHolding.getUserID(), getHolding
					.getHoldingID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetHoldingResponse response = new GetHoldingResponse();
		response.setGetHoldingReturn(factory.toHoldingData(holding));
		return response;
    }

    public GetTopOrdersResponse getTopOrders(
            @WebParam(name = "getTopOrders", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") GetTopOrders getTopOrders) {
        List<CustomOrderBean> topOrders;
		try {
			topOrders = mgr.getTopOrders(getTopOrders.getUserID());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		GetTopOrdersResponse response = new GetTopOrdersResponse();
		ArrayOfOrderDataBean param = new ArrayOfOrderDataBean();
        // FIXED: used array for metro generated code
        param.getOrderDataBean().addAll(factory.toOrderList(topOrders));
//		param.setOrderDataBean(toArray(topOrders));
		response.setGetTopOrdersReturn(param);
		return response;
    }

    public SellEnhancedResponse sellEnhanced(
            @WebParam(name = "sellEnhanced", targetNamespace = "http://trade.samples.websphere.ibm.com", partName =
                    "parameters") SellEnhanced sellEnhanced) {
        CustomOrderBean param;
		try {
			param = mgr.sellEnhanced(sellEnhanced.getUserID(), sellEnhanced
					.getHoldingID(), sellEnhanced.getQuantity());
		} catch (DAOException e) {
			logger.debug("", e);
			throw new RuntimeException(e);
		}
		SellEnhancedResponse response = new SellEnhancedResponse();
		response.setSellEnhancedReturn(factory.toOrder(param));
		return response;
    }
}
