/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader;

import java.math.BigDecimal;

/**
 * This class to be used as the data model for quote information.
 */
public class CustomQuoteBean {

	private static final long serialVersionUID = 7129349720689180586L;

    protected String symbol;
    protected String companyName;
    protected BigDecimal price;
    protected BigDecimal open;
    protected BigDecimal low;
    protected BigDecimal high;
    protected Double change;
    protected Double volume;

	public CustomQuoteBean() {
	}

	/**
	 * Constructs an instance for quote information.
	 * 
	 * @param symbol
	 * @param companyName
	 * @param volume
	 * @param price
	 * @param open
	 * @param low
	 * @param high
	 * @param change
	 */
	public CustomQuoteBean(String symbol, String companyName, double volume,
			BigDecimal price, BigDecimal open, BigDecimal low, BigDecimal high,
			double change) {
		setSymbol(symbol);
		setCompanyName(companyName);
		setVolume(volume);
		setPrice(price);
		setOpen(open);
		setLow(low);
		setHigh(high);
		setChange(change);
	}

    public String getSymbol() {
        return symbol;
    }

    public void setSymbol(String symbol) {
        this.symbol = symbol;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getOpen() {
        return open;
    }

    public void setOpen(BigDecimal open) {
        this.open = open;
    }

    public BigDecimal getLow() {
        return low;
    }

    public void setLow(BigDecimal low) {
        this.low = low;
    }

    public BigDecimal getHigh() {
        return high;
    }

    public void setHigh(BigDecimal high) {
        this.high = high;
    }

    public Double getChange() {
        return change;
    }

    public void setChange(Double change) {
        this.change = change;
    }

    public Double getVolume() {
        return volume;
    }

    public void setVolume(Double volume) {
        this.volume = volume;
    }
}
