/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader.mssql;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.stonehenge.stocktrader.dal.*;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

public class MSSQLDAOFactory extends DAOFactory {
    private static Log logger = LogFactory.getLog(MSSQLDAOFactory.class);
    private static MSSQLDAOFactory self = null;

    private Connection sqlConnection = null;

    private String connection = null;

    static {
        try {
            Class.forName("net.sourceforge.jtds.jdbc.Driver");
        } catch (ClassNotFoundException e) {
            logger.warn("Unable to load DBDrive class", e);
        }
    }

    public static DAOFactory getInstance() {
        if (self == null) {
            self = new MSSQLDAOFactory();
        }
        return self;
    }

    private MSSQLDAOFactory() {
    }

    public OrderDAO getOrderDAO() throws DAOException {
        logger.debug("MSSQLDAOFactory.getOrderDAO");
        try {
            OrderDAO orderDAO = new MSSQLOrderDAO(getConnection());
            return orderDAO;
        } catch (SQLException e) {
            logger.debug("", e);
            throw new DAOException(
                    "Exception was thrown when instantiating MSSQLOrderDAO object",
                    e);
        }
    }

    public CustomerDAO getCustomerDAO() throws DAOException {
        logger.debug("MSSQLDAOFactory.getOrderDAO");
        try {
            CustomerDAO customerDAO = new MSSQLCustomerDAO(getConnection());
            return customerDAO;
        } catch (SQLException e) {
            logger.debug("", e);
            throw new DAOException(
                    "Exception was thrown when instantiating a MSSQLCustomerDAO",
                    e);
        }
    }

    public MarketSummaryDAO getMarketSummaryDAO() throws DAOException {
        logger.debug("MSSQLDAOFactory.getOrderDAO");
        try {
            MarketSummaryDAO marketSummaryDAO = new MSSQLMarketSummaryDAO(
                    getConnection());
            return marketSummaryDAO;
        } catch (SQLException e) {
            logger.debug("", e);
            throw new DAOException(
                    "Exception was thrown when instantiating a MarketSummaryDAO",
                    e);
        }
    }

    private String getConnectionString() {
        if (connection == null) {
            loadProperties();
            if (prop == null) {
                connection = "jdbc:jtds:sqlserver://highlander:1433/StockTraderDB;user=trade;password=trade";
            } else {
                StringBuffer buf = new StringBuffer();
                buf.append("jdbc:jtds:sqlserver://");
                buf.append(prop.getProperty(PROP_DB_HOST));
                buf.append(":" + prop.getProperty(PROP_DB_PORT));
                buf.append("/" + prop.getProperty(PROP_DB_NAME));
                buf.append(";user=" + prop.getProperty(PROP_DB_USER));
                buf.append(";password=" + prop.getProperty(PROP_DB_PASSWORD));
                buf.append(";");
                connection = buf.toString();
            }
        }

        if (logger.isDebugEnabled()) {
            logger.debug("MSSQLDAOFactory.getConnectionString()\nConnection :" + connection);
        }
        return connection;
    }

    private Connection getConnection() throws SQLException {
        if (sqlConnection == null || sqlConnection.isClosed()) {
            sqlConnection = DriverManager.getConnection(getConnectionString());
        }
        return sqlConnection;
    }
}
