/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader.service;

import org.tempuri.OrderProcessorService;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.stonehenge.stocktrader.CustomOrderBean;
import org.apache.stonehenge.stocktrader.BeanFactory;
import org.apache.stonehenge.stocktrader.util.OrderProcessorUtility;
import org.apache.stonehenge.stocktrader.dal.DAOException;

import javax.jws.WebParam;
import javax.jws.WebService;

import traderorderhost.trade.SubmitOrder;
import traderorderhost.trade.IsOnline;
import com.ibm.websphere.samples.trade.OrderDataBean;

@WebService(endpointInterface = "org.tempuri.OrderProcessorService")
public class OrderProcessorImpl implements OrderProcessorService {
    private static final Log logger = LogFactory
			.getLog(OrderProcessorImpl.class);
	// OrderProcessManager is the controller for managing order processing.
	private final OrderProcessManager orderProcessManager = new OrderProcessManager();
    private final BeanFactory factory = new BeanFactory();

    public void submitOrder(@WebParam(name = "SubmitOrder", targetNamespace = "http://Trade.TraderOrderHost", partName =
            "parameters") SubmitOrder submitOrder) {
        OrderDataBean order = submitOrder.getOrder();
		CustomOrderBean orderData = factory.toCustomOrderBean(order);
		try {
			processOrder(orderData);
		} catch (DAOException e) {
			logger.error("", e);
		}
    }

    public void isOnline(@WebParam(name = "isOnline", targetNamespace = "http://Trade.TraderOrderHost", partName =
            "parameters") IsOnline parameters) {
        logger.debug("OrderProcessorImpl.isOnline(IsOnlines)");
    }

    private void processOrder(CustomOrderBean queueOrder) throws DAOException {
		// 2 seconds delay to ensure that MSFT-BL has committed new order
		// entries to the database which will happen when it gets HTTP 202
		// accepted header
		OrderProcessorUtility.pauseForTwoSeconds();
		orderProcessManager.processAndCompleteOrder(queueOrder);
	}
}
