/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader;

import java.math.BigDecimal;
import java.util.Calendar;

/**
 * This class is to be used as the data model for holding information.
 */
public class HoldingBean {

	private int accountId;
	private int holdingId;
	private double quantity;
	private BigDecimal purchasePrice;
	private Calendar purchaseDate;
	private String quoteId;

	public HoldingBean() {
	}

	/**
	 * Constructs a data model instance with holding information.
	 * 
	 * @param accountId the account ID of the buyer
	 * @param holdingId the holding ID of the stock 
	 * @param quantity the quantity of the stock
	 * @param purchasePrice the purchase price of the stock
	 * @param purchaseDate the date of the purchase of the stock
	 * @param quoteId the quote ID of the stock 
	 */
	public HoldingBean(int accountId, int holdingId, double quantity,
			BigDecimal purchasePrice, Calendar purchaseDate, String quoteId) {
		this.accountId = accountId;
		this.holdingId = holdingId;
		this.quantity = quantity;
		this.purchasePrice = purchasePrice;
		this.purchaseDate = purchaseDate;
		this.quoteId = quoteId;
	}

	public int getAccountId() {
		return accountId;
	}

	public void setAccountId(int accountId) {
		this.accountId = accountId;
	}

	public int getHoldingId() {
		return holdingId;
	}

	public void setHoldingId(int holdingId) {
		this.holdingId = holdingId;
	}

	public double getQuantity() {
		return quantity;
	}

	public void setQuantity(double quantity) {
		this.quantity = quantity;
	}

	public BigDecimal getPurchasePrice() {
		return purchasePrice;
	}

	public void setPurchasePrice(BigDecimal purchasePrice) {
		this.purchasePrice = purchasePrice;
	}

	public Calendar getPurchaseDate() {
		return purchaseDate;
	}

	public void setPurchaseDate(Calendar purchaseDate) {
		this.purchaseDate = purchaseDate;
	}

	public String getQuoteId() {
		return quoteId;
	}

	public void setQuoteId(String quoteId) {
		this.quoteId = quoteId;
	}
}
